Networks provide the communication channels for containers in the cloud.

|  | Network | Subnets Associated | Shared | Admin State | Status |
--- | --- | --- | --- | --- | --- | --- | ---
Select an item from Available items below
{$ $index + 1 $} |  | {$ row.name $} | {$ subnet.name $} | {$ row.shared | yesno $} | {$ row.admin_state | decode:ctrl.networkAdminStates $} | {$ row.status | decode:ctrl.networkStatuses $} |
ID {$ row.id $} Project {$ row.tenant_id $} External Network {$ row['router:external'] | yesno $} Provider Network Type {$ row['provider:network_type'] $} Segmentation ID {$ row['provider:segmentation_id'] $} Physical Network {$ row['provider:physical_network'] $}

| Network | Subnets Associated | Shared | Admin State | Status |
--- | --- | --- | --- | --- | --- | ---
No available items
| {$ row.name$} | {$ subnet.name $} | {$ row.shared | yesno $} | {$ row.admin_state | decode:ctrl.networkAdminStates $} | {$ row.status | decode:ctrl.networkStatuses $} |
ID {$ row.id $} Project {$ row.tenant_id $} External Network {$ row['router:external'] | yesno $} Provider Network Type {$ row['provider:network_type'] $} Segmentation ID {$ row['provider:segmentation_id'] $} Physical Network {$ row['provider:physical_network'] $}